#!/bin/sh
#*******************************************************************************
# Licensed Materials - Property of IBM
# (c) Copyright IBM Corporation 2001, 2016. All Rights Reserved.
#
# Note to U.S. Government Users Restricted Rights:  
# Use, duplication or disclosure restricted by GSA ADP Schedule 
# Contract with IBM Corp. 
#*******************************************************************************
_SCRIPT_TYPE=`type "$0"`
echo $_SCRIPT_TYPE | grep ')' > /dev/null
if [ $? -eq 0 ]; then
   # Assume that the type has been reported in the form:
   #    "baz is hashed (/foo/bar/baz)"
   # and extract the full path from within the parenthesis.
   #
   # NOTE: As this should be being executed in a newly created shell, this should
   #       not be needed.
   _SCRIPT=`echo $_SCRIPT_TYPE | sed 's/.* (\(.*\))/\1/g'`
else
   # Assume that the type has been reported in the form:
   #    "baz is /foo/bar/baz"
   # and just remove everything but the full path
   _SCRIPT=`echo $_SCRIPT_TYPE | sed 's/.*is //g'`
fi

_SCRIPTDIR=`dirname "$_SCRIPT"`
_RUNJAVA="$_SCRIPTDIR/../jre/bin/java"

if [ ! -x "$_RUNJAVA" ]; then
   _RUNJAVA=java
fi

# ******** Logging ********
# The following options are used to configure logging in the HTTP(S)/TCP Proxy.
#
# Option: -Djava.util.logging.config.file
#	This points to a configuration file that will be used to configure java's default logging framework.
#	This will be used in the case that the proxy's diagnostic logging service is using the default configuration
#	or has been configured to use a JULAppender (see below).
#
#	Proxy default: logging.properties
#
# Option: -Dgreenhat.logappender.<appender_type>.<appender_name>=<key1>:<value1>,<key2>:<value2>
# 	The greenhat.logappender option is used to configure diagnostic logging. This can communicate with a
#	running instance of the Rational Tester Control Panel so as to record log events to a central server.
#	The log appender type, name and key values are used to configure how the diagnostic logging operates
# 	and are described below. Some key values are optional.
#
# Diagnostic Logging:
#	Diagnostic logging is configured by specifying log appenders. A log appender will decide where to direct
#	log events to. There are three log appenders:
#		1. java.util.logging appender (JUL appender) - This appender will utilise the default java logging framework
#				for handling log events. This is configured via the properties file specified by the 
#				-Djava.util.logging.config.file option (see above).
#				
#				Configuration: -Dgreenhat.logappender.jul.<name>=(optional)level:<level>
#						<name> - Defines a symbolic name for the logger
#						level:<level> - Specifies that only log events equal to or higher than <level> should be
#										be passed on by the appender. If changes are made to the logging level for
#										the appender, the logging level set in the logging properties file pointed
#										to by the java.util.logging.config.file option may need to be changed to ensure
#										that the desired log events are logged.
#										The diagnostic logging service uses the following log levels:
#											ERROR
#											WARNING
#											INFO
#											DEBUG
#											TRACE		
#										Default value: DEBUG				
#					e.g. -Dgreenhat.logappender.jul.ONE=level:WARNING
#
#		2. Network appender (net appender) - This appender will communicate with a running instance of the Rational
#				Tester Control Panel and redirect log events there. Entries logged this way can be viewed on the
#				Diagnostic Logging tab of the Server Administration Panel in RTCP.
#
#				Configuration: -Dgreenhat.logappender.net.<name>=(optional)url:<host>:<port>/RTCP,(optional)level:<level>
#						<name> - Defines a symbolic name for the logger
#						url:<host>:<port>/RTCP - Specifies the host-name and port of the Rational Tester Control Panel server
#												 that the diagnostic logging service should send log events to.
#												 In order to specify the server that the proxy is configured to register with,
#												 the value can be set to 'auto'.
#												 Default Value: auto
#						level:<level> - Specifies that only log events equal to or higher than <level> should be
#										be passed on by the appender.
#										Default value: WARNING
#					e.g. -Dgreenhat.logappender.net.MYAPPENDER=url:http://localhost:7819/RTCP,level:debug
#
#		3. Console appender - This appender will handle log events within the application and display them on the application's
#				output console.
#				
#				Configuration: -Dgreenhat.logappender.console.<name>=(optional)layout:<layoutType>,(optional)level:<level>
#						<name> - Defines a symbolic name for the logger
#						layout:<layoutType> - Controls how the log event information should be formatted and laid out on the
#												console. Valid values are:
#													detailed, standard and compact
#												Default value: detailed
#						level:<level> - Specifies that only log events equal to or higher than <level> should be
#										be passed on by the appender.
#										Default value: INFO
#					e.g. -Dgreenhat.logappender.console.DEBUG=layout:detailed,level:debug
# ******** /Logging ********

# Start a proxy using default java.util.logging
"$_RUNJAVA" -Djava.util.logging.config.file="$_SCRIPTDIR/logging.properties" -cp "$_SCRIPTDIR/ghproxy.jar" com.greenhat.proxy.Main

# Start a proxy using diagnostic logging with a net appender.
#"$_RUNJAVA" -Djava.util.logging.config.file="$_SCRIPTDIR/logging.properties" -Dgreenhat.logappender.net.MYAPPENDER="url:http://localhost:7819/RTCP,level:debug" -cp "$_SCRIPTDIR/ghproxy.jar" com.greenhat.proxy.Main
